@@ -7,21 +7,27 @@ use std::path::Path;
 ///
 /// # Example
 /// ```
-/// use hyperlocal::Uri;
 /// use hyper::Uri as HyperUri;
+/// use hyperlocal::Uri;
 ///
 /// let uri: HyperUri = Uri::new("/tmp/hyperlocal.sock", "/").into();
 /// ```
-#[derive(Debug)]
+#[derive(Debug, Clone)]
 pub struct Uri {
     hyper_uri: HyperUri,
 }
 
 impl Uri {
     /// Create a new `[Uri]` from a socket address and a path
-    pub fn new(socket: impl AsRef<Path>, path: &str) -> Self {
+    ///
+    /// # Panics
+    /// Will panic if path is not absolute and/or a malformed path string.
+    pub fn new(
+        socket: impl AsRef<Path>,
+        path: &str,
+    ) -> Self {
         let host = hex::encode(socket.as_ref().to_string_lossy().as_bytes());
-        let host_str = format!("unix://{}:0{}", host, path);
+        let host_str = format!("unix://{host}:0{path}");
         let hyper_uri: HyperUri = host_str.parse().unwrap();
 
         Self { hyper_uri }
